@@ -22,7 +22,6 @@ pub const INSTRUCTION_UPDATE_STATE_AIRDROP_ACCOUNT:u8=18;
 pub const INSTRUCTION_INITIALIZE_PORTFOLIO:u8=19;
 pub const INSTRUCTION_CREATE_INIT_PPU:u8=20;
 pub const INSTRUCTION_CREATE_INIT_TURING_MASHINE:u8=38;
-pub const INSTRUCTION_CREATE_INIT_TRIGGUER_TURING_MASHINE:u8=39;
 pub const INSTRUCTION_UPDATE_STATE_INITIALIZE_PPM:u8=21;
 pub const INSTRUCTION_ADD_ASSET_TO_PORTFOLIO:u8=22;
 pub const INSTRUCTION_ADD_SPLU_TO_PPU:u8=23;
@@ -34,13 +33,12 @@ pub const INSTRUCTION_WITHDRAW_FROM_SABER:u8=28;
 pub const INSTRUCTION_SWAP_REVERTE:u8=29;
 pub const INSTRUCTION_CEARTE_MINER:u8=30;
 pub const INSTRUCTION_TRANSFER_WITH_CROSS:u8=31;
-pub const INSTRUCTION_UPDATE_SPLU_PPU:u8=32;
+pub const INSTRUCTION_UPDATE_SPLU_TURING_MASHINE:u8=32;
 pub const INSTRUCTION_UPDATE_SPLU_TERTIARY_PPU:u8=33;
 pub const INSTRUCTION_RESET_SPLU_TERTIARY_PPU:u8=34;
 pub const INSTRUCTION_CLAIM_REWARDS:u8=35;
 pub const INSTRUCTION_TRANSFER_REWARDS:u8=36;
 pub const INSTRUCTION_INVEST_MORE:u8=37;
-pub const INSTRUCTION_MINT_MORE_N_ASSET:u8=38;
 pub const EXTERNAL_INSTRUCTION_WITHDRAW_SABER: u8 = 3;
 pub const WITHDRAW_INSTRUCTION_SABER: u8 = 3;
 pub const EXTERNAL_INSTRUCTION_APPROVE_SPL: u8 = 4;
